@@ -243,6 +243,13 @@ setReplaceMethod("bpworkers", c("SnowParam", "numeric"),
     x
 })
 
+setReplaceMethod("bpworkers", c("SnowParam", "character"),
+    function(x, value)
+{
+    x$workers <- x$.clusterargs$spec <- value
+    x
+})
+
 setMethod("bpRNGseed", "SnowParam",
     function(x)
 {
@@ -286,7 +293,8 @@ setMethod("bpstart", "SnowParam",
         cargs$spec <- if (is.numeric(cargs$spec)) {
             nnodes
         } else cargs$spec[seq_len(nnodes)]
-        cargs$snowlib <- find.package("BiocParallel")
+        if (is.null(cargs$snowlib))
+            cargs$snowlib <- find.package("BiocParallel")
         if (!is.null(cargs$useRscript) && !cargs$useRscript)
             cargs$scriptdir <- find.package("BiocParallel")
 
