@@ -1,10 +1,3 @@
-.paramFields <-
-    function(generator)
-{
-    result <- generator$fields()
-    result[setdiff(names(result), names(.BiocParallelParam$fields()))]
-}
-
 .splitIndices <- function (nx, tasks)
 {
     ## derived from parallel
