@@ -5,7 +5,7 @@
 
 ${RPROG:-R} --vanilla <<EOF > ${OUT:-/dev/null} 2>&1 &
 
-library(snow)
+loadNamespace("snow")
 options(timeout=getClusterOption("timeout"))
-BiocParallel::bpslaveLoop(makeSOCKmaster())
+BiocParallel::bploop(snow::makeSOCKmaster())
 EOF
