@@ -8,9 +8,9 @@ test_SnowParam_construction <- function()
 
 test_SnowParam_SOCK <- function() 
 {
-    if (!suppressWarnings(require(snow)))
-        ## quietly succeed if 'snow' not available
-        return()
+    if (!requireNamespace("snow", quietly=TRUE))
+        DEACTIVATED("'snow' package did not load")
+
     param <- SnowParam(2, "SOCK", tasks=2)
     checkIdentical(FALSE, bpisup(param))
 
@@ -19,10 +19,18 @@ test_SnowParam_SOCK <- function()
     checkIdentical(FALSE, bpisup(param))
 }
 
+test_SnowParam_SOCK_character <- function()
+{
+    bpstop(bpstart(SnowParam("localhost")))
+}
+
 test_SnowParam_MPI <- function() 
 {
     if (.Platform$OS.type == "windows")
-        return()
+        DEACTIVATED("MPI tests not run on Windows")
+
+    DEACTIVATED("MPI tests not run")
+
     param <- SnowParam(2, "MPI", tasks=2)
     checkIdentical(FALSE, bpisup(param))
 
@@ -33,9 +41,8 @@ test_SnowParam_MPI <- function()
 
 test_SnowParam_coerce_from_SOCK <- function()
 {
-    if (!suppressWarnings(require(snow)))
-        ## quietly succeed if 'snow' not available
-        return(TRUE)
+    if (!requireNamespace("snow", quietly=TRUE))
+        DEACTIVATED("'snow' package did not load")
 
     cl <- parallel::makeCluster(2L, "SOCK")
     p <- as(cl, "SnowParam")
@@ -59,11 +66,13 @@ test_SnowParam_coerce_from_SOCK <- function()
 test_SnowParam_coerce_from_MPI <- function()
 {
     if (.Platform$OS.type == "windows")
-        return()
-    if (!(suppressWarnings(require(snow)) ||
-          suppressWarnings(require(Rmpi))))
-        ## quietly succeed if 'snow', 'Rmpi' not available
-        return()
+        DEACTIVATED("MPI tests not run on Windows")
+    
+    if (!requireNamespace("snow", quietly=TRUE) ||
+         !requireNamespace("Rmpi", quietly=TRUE))
+        DEACTIVATED("'snow' and/or 'Rmpi' package did not load")
+
+    DEACTIVATED("MPI tests not run")
 
     cl <- parallel::makeCluster(2L, "MPI")
     p <- as(cl, "SnowParam")
@@ -88,10 +97,10 @@ test_SnowParam_workers <- function()
 {
     if (.Platform$OS.type == "windows")
         return()
-    if (!(suppressWarnings(require(snow)) ||
-          suppressWarnings(require(Rmpi))))
-        ## quietly succeed if 'snow', 'Rmpi' not available
-        return()
+
+    if (!requireNamespace("snow", quietly=TRUE) ||
+         !requireNamespace("Rmpi", quietly=TRUE))
+        DEACTIVATED("'snow' and/or 'Rmpi' package did not load")
 
     checkException(SnowParam("host", "MPI"), silent=TRUE)
     checkException(SnowParam("host", "FORK"), silent=TRUE)
