@@ -1,14 +1,21 @@
-library(doParallel)
 quiet <- suppressWarnings
 
+test_bpmapply_MoreArgs_names <- function()
+{
+    ## https://github.com/Bioconductor/BiocParallel/issues/51
+    f <- function(x, y) x
+    target <- bpmapply(f, 1:3, MoreArgs=list(x=1L))
+    checkIdentical(rep(1L, 3), target)
+}
+
 test_bpmapply_Params <- function() 
 {
     if (.Platform$OS.type != "windows") {
-        registerDoParallel(2)
+        doParallel::registerDoParallel(2)
         params <- list(serial=SerialParam(),
                        snow=SnowParam(2),
                        dopar=DoparParam(),
-                       batchjobs=BatchJobsParam(progressbar=FALSE),
+                       batchjobs=BatchJobsParam(2, progressbar=FALSE),
                        mc <- MulticoreParam(2))
 
         x <- 1:10
@@ -16,9 +23,9 @@ test_bpmapply_Params <- function()
         f <- function(x, y) x + y
         expected <- x + y
         for (param in params) {
-          current <- quiet(bpmapply(f, x, y, BPPARAM=param))
-          checkIdentical(expected, current)
-          closeAllConnections()
+            current <- quiet(bpmapply(f, x, y, BPPARAM=param))
+            checkIdentical(expected, current)
+            closeAllConnections()
         }
 
         # test names and simplify
@@ -69,7 +76,7 @@ test_bpmapply_Params <- function()
 
 test_bpmapply_symbols <- function()
 {
-    registerDoParallel(2)
+    doParallel::registerDoParallel(2)
     params <- list(serial=SerialParam(),
                    snow=SnowParam(2),
                    dopar=DoparParam())
